@@ -24,7 +24,7 @@
 //! - While _classes_ of status codes are the same (Success 2xx -> 2.xx, Client error 4xx -> 4.xx, Server error 5xx -> 5.xx), the semantics of the individual response codes differ.
 
 // docs
-#![doc(html_root_url = "https://docs.rs/kwap/0.5.5")]
+#![doc(html_root_url = "https://docs.rs/kwap/0.6.0")]
 #![cfg_attr(any(docsrs, feature = "docs"), feature(doc_cfg))]
 // -
 // style
@@ -51,26 +51,26 @@ pub mod todo;
 #[cfg(test)]
 pub(crate) mod test;
 
-/// Blocking CoAP client & server
+/// Blocking rust CoAP client & server
 pub mod blocking;
 
-/// Customizable retrying of fallible operations
+/// customizable retrying of fallible operations
 pub mod retry;
 
-/// CoAP response messages
+/// responses
 pub mod resp;
 
-/// CoAP request messages
+/// requests
 pub mod req;
 
-/// CoAP client
+/// low-level coap behavior
 pub mod core;
 
-/// kwap configuration
-pub mod config;
+/// platform configuration
+pub mod platform;
 
-/// sockets
-pub mod socket;
+/// network abstractions
+pub mod net;
 
 /// `std`-only kwap stuff
 #[cfg(feature = "std")]
